DatabaseInfo class

Inheritance

Constructors

DatabaseInfo()

Properties

dbHandler ↔ DBHandler?
getter/setter pairinherited
fields ↔ Map<String, Map<String, dynamic>>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ String
getter/setter pairinherited

Methods

checkStackStatus(int stack, String name) → bool
inherited
deleteRecord({String condition = ""}) → Future<Map<String, dynamic>>
inherited
fetchDistinctRecords({String condition = "", String distinctField = "", String fetchMode = "LIST", String limitCondition = ""}) → Future<Map<String, dynamic>>
inherited
fetchQueryRecords({String fetchMode = "LIST", String query = "", Map<String, List<String>> formatColumns = const {}}) → Future<Map<String, dynamic>>
inherited
fetchRecords({String condition = "", String fetchMode = "LIST", String limitCondition = ""}) → Future<Map<String, dynamic>>
inherited
formatValues() → dynamic
inherited
getCreateTableQuery() → String
inherited
getDoubleValue(String name) → double
inherited
getField({String name = "", List? attributes}) → Map<String, dynamic>
inherited
getFieldAttributes(String name) → List<String>
inherited
getFieldFormats() → Map<String, List<String>>
inherited
getFieldSQLValue(String fieldName) → String
inherited
getFieldValue(String name) → dynamic
inherited
getIntValue(String name) → int
inherited
getSelectQuery() → String
inherited
getSelectQueryFieldsWithCondition({String queryMode = "", List skipFields = const []}) → String
inherited
getStringValue(String name) → String
inherited
getTableViewName() → String
inherited
getUserDefinedFunction(String name) → Map<String, dynamic>
inherited
getViewQuery() → String
inherited
insertRecord({Map<String, dynamic> insertParams = const {}}) → Future<Map<String, dynamic>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveRecord() → Future<Map<String, dynamic>>
inherited
setDatabase(String path) → void
inherited
setFieldValue(String name, dynamic value) → void
inherited
setObjectValues(Map<String, dynamic> values) → void
inherited
toString() → String
A string representation of this object.
inherited
updateRecord({int stack = 0}) → Future<Map<String, dynamic>>
inherited
updateUserDefinedFunction(Map<String, dynamic> userDefinedFunctions, String name) → Map<String, dynamic>
inherited
validateValues() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

dbInfoKey → const String
dbInfoValue → const String
TABLE_NAME → const String