EnvironmentConfig class

Constructors

EnvironmentConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

config ↔ Map<String, dynamic>
getter/setter pair
env ↔ String
getter/setter pair
envDev ↔ String
getter/setter pair
envProd ↔ String
getter/setter pair
envStage ↔ String
getter/setter pair

Static Methods

init({String environment = "", Map<String, dynamic> configs = const {}}) → dynamic